@@ -1,3 +1,4 @@
+"""Top-level janitor API lives here."""
 try:
     import janitor.xarray  # noqa: F401
 except ImportError:
@@ -16,7 +17,8 @@ from .utils import refactored_function
     "get_features_targets() has moved. Please use ml.get_features_targets()."
 )
 def get_features_targets(*args, **kwargs):
+    """Wrapper for get_features_targets."""
     return _get_features_targets(*args, **kwargs)
 
 
-__version__ = "0.20.5"
+__version__ = "0.20.7"
